@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1998/07/21 09:19:17 $
-# $Revision: 1.18.1.172 $
+# $Date: 1998/08/19 12:17:29 $
+# $Revision: 1.18.1.176 $
 #
 #
 package provide zircon 1.18
@@ -862,8 +862,7 @@ proc makeCtlInfo {this net w chan rchan idx look} {
 	$omm add command -label [trans new] -command "$this newMsg"
 	$omm add separator
 	foreach x [$this messages] {
-	    $omm.menu add command -label [prune $x 15] \
-	      -command "$this send [list $x]"
+	    $omm add command -label [prune $x 15] -command "$this send [list $x]"
 	}
 	$om add command -command "\[$this dwin\] show" -label [trans draw]
 	if {![$this draw]} { $om entryconfigure 3 -state disabled }
@@ -1058,7 +1057,8 @@ proc channel_keepMsg {this str} {
 	$this send $str
 	[$this window].channel.menu.msgs add command \
 	  -label "[prune $str 15]" -command "$this send [list $str]"
-	[$this net] configure +messages $str +confChange Channels
+	$this configure +messages $str
+	[$this net] configure +confChange Channels
     }
 }
 #
@@ -1280,19 +1280,20 @@ proc channel_clear {this hist} {
 	$t configure -state disabled
     } {
 	if {![tk_dialog .@clr$this [trans clear] "Due to a change in the way that\
-	tk handles text windows it is no longer possible to make the clear function\
-	clear only the viewable area.
+tk handles text windows it is no longer possible to make the clear function\
+clear only the viewable area.
 	
 You can however clear the window AND ALL THE SCROLLBACK BUFFER.
 	
 Click \"Yes\" if you wish to do this.
 
-If you do not want to see this message again Shift-Click on the Clear button" info 0 \
+Shift-Clicking the Clear button will always do this\
+and you won't see this message..." info 0 \
 	[trans Yes] [trans No]]} {
+	    $t configure -state normal
+	    $t delete 1.0 end
+	    $t configure -state disabled
 	}
-	$t configure -state normal
-	$t delete 1.0 end
-	$t configure -state disabled
     }
 }
 #
@@ -1762,55 +1763,51 @@ proc valCmp {this op ln def dc} {
     return $ln
 }
 #
-proc mncSave {desc this defA} {
-    global rcSave rcOpt defaultNet
+proc mncSave {desc this defA TVar} {
+    global defaultNet Channel
+    upvar #0 $TVar config
+    array set cvals $Channel
+    array set cvals $config
     set def [getDefault $defA [$this net]]
     set dc [getDefault $defA $defaultNet]
     set typ [$this type]
     set ln {}
-    foreach x [concat $rcSave(all) $rcSave($typ)] {
-	set ln [valCmp $this $x $ln $def $dc]
-    }
     upvar #0 $this cdata
-    foreach x [concat $rcOpt(all) $rcOpt($typ)] {
+    foreach x [array names cvals] {
 	switch {} $cdata($x) {} default {
 	    set ln [valCmp $this $x $ln $def $dc]
 	}
     }
-    switch {} $ln return
-    puts $desc "$typ [list [$this name]] $ln"
+    switch {} $ln {
+        puts $desc "$typ [list [$this name]]"
+    } default {
+	puts $desc "$typ [list [$this name]] $ln"
+    }
 }
 #
 proc channel_save {this desc} {
-    mncSave $desc $this defChan
+    mncSave $desc $this defChan Channel
     foreach b [$this bindings] {
 	puts $desc "zbind [$this name] [lindex $b 0] [list [lindex $b 1]]"
     }
 }
 #
-proc defSave {desc array net args} {
-    global rcSave rcOpt zDefs Channel defaultNet Private.Channel
-    upvar #0 $array defObj
+proc defSave {desc array net TVar} {
+    global zDefs defaultNet Channel
+    upvar #0 $TVar conf $array defObj
+    array set zDefs $Channel
+    array set zDefs $conf
     set adf $defObj($defaultNet)
     set def $defObj($net)
-    array set zDefs $Channel
-    catch {array set zDefs ${Private.Channel}}
-    foreach x $args {
-	global $x Private.$x
-	array set zDefs [set $x]
-	catch {array set zDefs [set Private.$x]}
-    }
-    set typ [$def type]
-    set vars [concat $rcSave(all) $rcSave($typ) $rcOpt(all) $rcOpt($typ)]
     switch -- $def $adf {
-	foreach x $vars {
+	foreach x [array names zDefs] {
 	    switch -- $zDefs($x) [$def $x] {} default {
 	    	$def save $desc
 		return
 	    }
 	}
     } default {
-	foreach x $vars {
+	foreach x [array names zDefs] {
 	    switch -- [$adf $x] [$def $x] {} default {
 	    	$def save $desc
 		return
@@ -1822,7 +1819,7 @@ proc defSave {desc array net args} {
 #
 proc Channel_save {desc net} {
     global defChan
-    defSave $desc defChan $net
+    defSave $desc defChan $net Channel
     foreach ch [$net channels] {
 	switch -- $ch $defChan($net) continue
 	if {![$ch sys] && [$ch keep]} {$ch save $desc}
