@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Chat.tcl,v $
-# $Date: 1998/04/28 13:15:16 $
-# $Revision: 1.18.1.43 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Chat.tcl,v $
+# $Date: 1998/07/23 13:47:59 $
+# $Revision: 1.18.1.44 $
 #
 package provide zircon 1.18
 #
@@ -157,7 +157,7 @@ proc Chat_find {name net} {
 #
 proc Chat_save {desc net} { defSave $desc defChat $net DChat }
 #
-proc chat_save {this desc} { }
+proc chat_save {this desc} { mncSave $desc $this defChat DChat }
 #
 proc ChatServer {usr nk} {
     set net [$usr net]
