@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Classes.tcl,v $
-# $Date: 1998/07/16 11:11:11 $
-# $Revision: 1.18.1.88 $
+# $Date: 1998/08/19 12:17:31 $
+# $Revision: 1.18.1.89 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -216,8 +216,7 @@ global zircon
 class Net "
     beep	BEEP	{text}
     busymsg	{I am busy and am not accepting calls at the moment.} {text}
-    wavplayer	{}	{program}
-    wavpath	{}	{path}
+    players	{}	{list}
     setcolour	red	{colour}
     foreground	$zircon(fg)	{colour}
     myaddr	{}	{host}
