@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/07/21 12:59:28 $
-# $Revision: 1.18.1.152 $
+# $Date: 1998/08/18 11:16:11 $
+# $Revision: 1.18.1.153 $
 #
 package provide zircon 1.18
 #
@@ -30,7 +30,7 @@ proc Net {name args} {
     foreach x {Get Send Resume Offer AChat} {
 	uplevel #0 trace variable $x$this u unsetSGO
     }
-    array set ndata "name $name"
+    set ndata(name) $name
     uplevel #0 lappend znetList $this
     return $this
 }
