@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/User.tcl,v $
-# $Date: 1998/04/15 12:56:08 $
-# $Revision: 1.18.1.42 $
+# $Date: 1998/05/07 11:01:25 $
+# $Revision: 1.18.1.43 $
 #
 package provide zircon 1.18
 #
@@ -112,50 +112,6 @@ proc user_mode {this mode args} {
     [$this net] send MODE [$this name] $mode [lindex $args 0]
 }
 #
-set zFileTypes {
-  {{All Files}		{*}				}
-  {{Gif Images}		{.gif .GIF}			}
-  {{Gif Images}		{}				GIFF}
-  {{JPEG Images}	{.jpg .JPG .jpeg .JPEG}		}
-  {{JPEG Images}	{}				JFIF}
-  {{Wav Sounds}		{.wav .WAV}			}
-}
-#
-proc user_heal {this} {
-    global Split Heal TSplit
-    set told 0
-    set net [$this net]
-    foreach sl [array names Split] {
-	if {[set x [lsearch $Split($sl) $this]] >= 0} {
-	    catch {after cancel $TSplit($sl) ; unset TSplit($sl)}
-	    if {![info exists Heal($sl)]} {
-		set told 1
-		[$net info] optText HEAL "*** Heal - $sl"
-		handleOn $net HEAL $sl
-	    }
-	    set v $Split($sl)
-	    listdel v $x
-	    $this deref
-	    switch {} $v {
-		    unset Split($sl)
-		    catch {after cancel Heal($sl) ; unset Heal($sl)}
-	    } default {
-		set Split($sl) $v
-		catch {after cancel $Heal($sl)}
-		set Heal($sl) [after 120000 $net cleanSplit "{$sl}"]
-	    }
-	}
-    }
-    foreach x {Notice Message} {
-	switch nil [set id [$x :: find [$this lname] $net]] continue 
-	if {[$id active]} {
-	    $id addText {} {*** Heal}
-	    $id flag normal
-	}
-    }
-    foreach x [$net channels] { $x heal $this }
-}
-#
 proc user_kill {this} { kill [$this net] [$this name] }
 #
 proc user_protect {this chan culprit mode} {
@@ -165,7 +121,7 @@ proc user_protect {this chan culprit mode} {
     }
     set nm [$chan name]
     foreach x [$frd protect] {
-	if {[regexp -nocase [lindex $x 0] $nm]} {
+	if {[regexp -nocase -- [lindex $x 0] $nm]} {
 	    foreach y [lindex $x 1] {
 	        if {[regexp -- [lindex $y 0] $mode]} {
 		    friendAction $this $chan $culprit [lindex $y 1]
@@ -192,27 +148,6 @@ proc user_unpack {this net} {
     unset ${net}UTO([$this lname])
 }
 #
-proc user_split {this split} {
-    global Split
-    set net [$this net]
-    if {![info exists Split($split)]} { $net newSplit $split }
-    foreach id [$net channels] {$id userSplit $this $split}
-    foreach x {Notice Message} {
-	switch nil [set id [$x :: find [$this lname] $net]] continue
-	if {[$id active]} {
-	    $id addText {} "*** Netsplit - $split"
-	    $id flag disabled
-	}
-    }
-    switch nil [set fobj [$this fobj]] {} default {
-	[$net finfo] disable $fobj
-	$fobj configure -limbo 1
-    }
-    lappend Split($split) $this
-    $this ref
-    handleOn $net USPLIT [list $split [$this lname]]
-}
-#
 # Procs for the class User
 #
 #
