@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Util.tcl,v $
-# $Date: 1998/07/16 11:11:18 $
-# $Revision: 1.18.1.74 $
+# $Date: 1998/08/19 12:17:36 $
+# $Revision: 1.18.1.75 $
 #
 package provide zircon 1.18
 #
@@ -99,7 +99,7 @@ proc addCTCPMenu {net name usr} {
     $name add cascade -label [trans ctcp] -menu $name.ctcp
     menu $name.ctcp 
     set cmdlst $ctcpCmds
-    switch {} [$net wavplayer] {} default { lappend cmdlst Sound }
+    switch {} [$net players] {} default { lappend cmdlst Sound }
     if {$DEBUG} { lappend cmdlst Zircon }
     foreach cmd $cmdlst {
 	switch {{}} $usr {
