@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/initial.tcl,v $
-# $Date: 1998/07/16 11:11:21 $
-# $Revision: 1.18.1.173 $
+# $Date: 1998/08/19 12:17:40 $
+# $Revision: 1.18.1.174 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -34,8 +34,6 @@ proc net {var val} {
     zircon(images) -
     zircon(raw) -
     zircon(command) -
-    zircon(wavplayer) -
-    zircon(wavpath) -
     zircon(nicksize) -
     zircon(antiflood) -
     zircon(ircIImode) -
@@ -44,6 +42,10 @@ proc net {var val} {
 	    regexp {.*\((.*)\)} $var m op
 	    $currentNet configure -$op $val
 	}
+    zircon(wavpath) -
+    wavpath { $currentNet addWP $val }
+    zircon(wavplayer) -
+    wavplayer { $currentNet addWPl $val }
     meta { set zircon(meta) $val }
     autoAway -
     ping -
