@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/tcl75.tcl,v $
-# $Date: 1998/02/09 16:57:13 $
-# $Revision: 1.18.1.18 $
+# $Date: 1998/07/24 15:10:29 $
+# $Revision: 1.18.1.19 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -46,3 +46,11 @@ proc sendSound {net nk} {
 	[trans sound] $msg {} \
 	"send {doSendSound $net $nk}" "cancel {}"]
 }
+#
+proc native {fl} { return $fl }
+#
+proc noCase {t1 t2} {
+    return [string compare [string tolower $t1] [string tolower $t2]]
+}
+#
+proc ncsort {lst} { return [lsort -command noCase $lst] }
