@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/tcl80.tcl,v $
-# $Date: 1998/02/09 16:57:14 $
-# $Revision: 1.18.1.2 $
+# $Source: /home/nlfm/Zircon/lib/RCS/tcl80.tcl,v $
+# $Date: 1998/08/19 12:17:42 $
+# $Revision: 1.18.1.5 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -36,12 +36,20 @@ proc sendSound {net nk} {
     global SoundDir zircon
     if {![info exists SoundDir($net)]} {
 	if {[file exists [file join $zircon(prefdir) sounds]]} {
-	    set SoundDir($net) $zircon(prefdir)/sounds
+	    set SoundDir($net) [file join $zircon(prefdir) sounds]
 	} {
 	    set SoundDir($net) [file join $zircon(lib) sounds]
 	}
     }
+    set fts {}
+    foreach x [$net players] {
+        lappend fts [list [lindex $x 3] [lindex [lindex $x 0] 0]]
+    }
+    lappend fts [list {All files} {*.*}]
     doSendSound $net $nk [tk_getOpenFile -defaultextension wav \
-      -filetypes {{{Wav format sound files} {.\[wW\]\[aA\]\[vV\]}}} \
-      -initialdir $SoundDir($net)]
+      -filetypes $fts -initialdir $SoundDir($net)]
 }
+#
+proc native {fl} { return [file nativename $fl] }
+#
+proc ncsort {lst} { return [lsort -dictionary $lst] }
