@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/send.tcl,v $
-# $Date: 1998/04/27 11:46:15 $
-# $Revision: 1.18.1.28 $
+# $Source: /home/nlfm/Zircon/plugins/Dcc/RCS/send.tcl,v $
+# $Date: 1998/07/21 12:59:36 $
+# $Revision: 1.18.1.29 $
 #
 package provide Dcc 1.18
 #
@@ -63,10 +63,17 @@ proc handleInfo {net conn} {
 #
 proc endDCC {type who conn net msg args} {
     upvar #0 $type$net gsnet
-    set x [lsearch $gsnet($who) "$conn *"]
-    set file [lindex [lindex $gsnet($who) $x] 1]
-    listdel gsnet($who) $x
-    switch {} $gsnet($who) {unset gsnet($who)}
+    if {![catch {lsearch $gsnet($who) "$conn *"} x]} {
+        set file [lindex [lindex $gsnet($who) $x] 1]
+        listdel gsnet($who) $x
+        switch {} $gsnet($who) {unset gsnet($who)}
+    } {
+#
+# This should really never happen, but it does seem to sometimes
+# so rather than try to find the real cause, I'll just trap the error....
+#
+        set file {}
+    }
     if {![winfo exists .@$conn]} {
 	$net inform $msg
     } {
